@@ -8,18 +8,20 @@
 #include <stdlib.h>
 #include "libjodycode.h"
 
+static const char msg_unknown[] = "(unknown)";
+
 /* Out of memory failure */
-extern void jc_oom(const char * const restrict msg)
+extern void jc_oom(const char * restrict msg)
 {
-  fprintf(stderr, "\nout of memory: %s\n", msg);
-  exit(EXIT_FAILURE);
+	if (msg == NULL) msg = msg_unknown;
+	fprintf(stderr, "\nout of memory: %s\n", msg);
+	exit(EXIT_FAILURE);
 }
 
 /* Null pointer failure */
 extern void jc_nullptr(const char * restrict func)
 {
-  static const char n[] = "(NULL)";
-  if (func == NULL) func = n;
-  fprintf(stderr, "\ninternal error: NULL pointer passed to %s\n", func);
-  exit(EXIT_FAILURE);
+	if (func == NULL) func = msg_unknown;
+	fprintf(stderr, "\ninternal error: NULL pointer caught at %s\n", func);
+	exit(EXIT_FAILURE);
 }
